
/*-----------------------------------------------------------------------------------------------------------------------------------

■ 概要
予めアイテムに指定した量だけ、任意のタイミングでアイテムの使用回数を回復させます。

■ 使い方
アイテムのカスタムパラメータに{RecoveryDurability: X}で回復する使用回数を指定。
スクリプトの実行、コード実行から RecoveryDurabilityAll() メソッド 呼び出すことで指定された分の使用回数を回復する。
RecoveryDurabilityAll(true) とすれば使用回数を最大値まで回復する。

■ 作成者
Chaos Gate
http://kwt.web2.jp/

■ 利用条件
・SRPG Studioの利用規約に準じます(http://srpgstudio.com/guide/rules.html)
・この作品はクリエイティブ・コモンズ・表示 - 継承 4.0 国際・ライセンスで提供されています。
  日本語 http://creativecommons.org/licenses/by-sa/4.0/deed.ja
  English http://creativecommons.org/licenses/by-sa/4.0/

■ 更新履歴
2016/07/15 公開

-------------------------------------------------------------------------------------------------------------------------------------*/

// 全てのアイテムの使用回数を回復する
function RecoveryDurabilityAll(fullRecovery)
{
	// プレイヤー所持アイテムの回復
	var playerList = PlayerList.getMainList();
	var playerListCount = playerList.getCount();
	var maxItemCount = DataConfig.getMaxUnitItemCount();
	for(var i = 0; i < playerListCount; ++i)
	{
		var unit = playerList.getData(i);
		for (j = 0; j < maxItemCount; j++)
		{
			var item = unit.getItem(j);
			if(item) RecoveryDurability(item, fullRecovery);
		}
	}

	// ストックアイテムの回復
	var stockItems = StockItemControl.getStockItemArray();
	var stockItemCount = StockItemControl.getStockItemCount();
	for(var i = 0; i < stockItemCount; ++i) RecoveryDurability(stockItems[i], fullRecovery);
}

// 指定アイテムの使用回数を回復する
function RecoveryDurability(item, fullRecovery)
{
	if(typeof item.custom.RecoveryDurability !== 'number') return; // RecoveryDurabilityの指定がないものは対象にしない
	if(typeof fullRecovery === 'undefined') fullRecovery = false; // 引数の指定がなければ偽として扱う

	var limit = item.getLimit();
	if(limit == 0) return; // 使用回数０は無制限扱いなので回復しない
	var limitMax = item.getLimitMax();

	if(fullRecovery) limit = limitMax;
	else
	{
		if (limit <= WeaponLimitValue.BROKEN) limit = 0;
		limit = limit + item.custom.RecoveryDurability;
		limit = limit <= 0 ? WeaponLimitValue.BROKEN : Math.min(limit, limitMax);
	}
	item.setLimit(limit);
}
