
/*--------------------------------------------------------------------------

■ 概要
ステータスが画面などで、アイテムの最大使用回数も表示する。
また、壊れたアイテムの使用回数が「使用回数無限の表示」になるのを修正する。

■ 作成者
Chaos Gate
http://kwt.web2.jp/

■ 利用条件
・SRPG Studioの利用規約に準じます(http://srpgstudio.com/guide/rules.html)
・この作品はクリエイティブ・コモンズ・表示 - 継承 4.0 国際・ライセンスで提供されています。
  日本語 http://creativecommons.org/licenses/by-sa/4.0/deed.ja
  English http://creativecommons.org/licenses/by-sa/4.0/

■ 更新履歴
2016/07/15 公開

--------------------------------------------------------------------------*/

(function() {

var LimitlessString = '-/-';

// アイテム描画
ItemRenderer.drawItem = function(x, y, item, color, font, isDrawLimit)
{
	var interval = this._getItemNumberInterval();
	var iconWidth = GraphicsFormat.ICON_WIDTH + 5;
	var length = this._getTextLength();
	var handle = item.getIconResourceHandle();
	
	GraphicsRenderer.drawImage(x, y, handle, GraphicsType.ICON);
	
	TextRenderer.drawKeywordText(x + iconWidth, y, item.getName(), length, color, font);
	
	if (isDrawLimit) {
		if (this._isInfinity(item)) {
			return;
		}
		
		var text
		x = x + iconWidth + interval;
		var itemLimit = item.getLimit();
		if (itemLimit != 0)
		{
			if(itemLimit === WeaponLimitValue.BROKEN) itemLimit = 0;
			text = itemLimit + "/" + item.getLimitMax();
		}
		else
		{
			text = LimitlessString;
		}
		TextRenderer.drawKeywordText(x + 10 - TextRenderer.getTextWidth(text, font), y, text, -1, ColorValue.INFO, font);
	}
}

// アイテム半透明描画
ItemRenderer.drawItemAlpha = function(x, y, item, color, font, isDrawLimit, alpha)
{
	var interval = this._getItemNumberInterval();
	var iconWidth = GraphicsFormat.ICON_WIDTH + 5;
	var length = this._getTextLength();
	var handle = item.getIconResourceHandle();
	var graphicsRenderParam = StructureBuilder.buildGraphicsRenderParam();
	
	graphicsRenderParam.alpha = alpha;
	GraphicsRenderer.drawImageParam(x, y, handle, GraphicsType.ICON, graphicsRenderParam);
	
	TextRenderer.drawAlphaText(x + iconWidth, y + 5, item.getName(), length, color, alpha, font);
	
	if (isDrawLimit) {
		if (this._isInfinity(item)) {
			return;
		}
		
		var text;
		x = x + iconWidth + interval;
		var itemLimit = item.getLimit();
		if (itemLimit != 0)
		{
			if(itemLimit === WeaponLimitValue.BROKEN) itemLimit = 0;
			text = itemLimit + "/" + item.getLimitMax();
		}
		else
		{
			text = LimitlessString;
		}
		TextRenderer.drawKeywordText(x + 10 - TextRenderer.getTextWidth(text, font), y, text, -1, ColorValue.INFO, font);
	}
}

})();
